<?php

namespace Drupal\blazy;

/**
 * Provides common non-media related methods across Blazy ecosystem to DRY.
 */
abstract class BlazyBase implements BlazyInterface {

  /**
   * {@inheritdoc}
   */
  public function merge(array $data, array $element, $key = NULL): array {
    return Blazy::merge($data, $element, $key);
  }

  /**
   * {@inheritdoc}
   */
  public function config(
    $key = '',
    $default = NULL,
    $id = 'blazy.settings',
    array $defaults = []
  ) {
    $config = variable_get($id, $defaults);

    // Somebody likes deleting variables for no apparent reasons, make em happy.
    if (!$config) {
      return $default;
    }

    if (!$key) {
      return $config;
    }

    // Support once level array with dot notation.
    if (strpos($key, ".") !== FALSE) {
      $parts = explode(".", $key);
      // @todo $value = NestedArray::getValue($config, (array) $parts);
      $value = $config[$parts[0]][$parts[1]] ?? $default;
    }
    else {
      $value = $config[$key] ?? $default;
    }

    return $value;
  }

  /**
   * {@inheritdoc}
   */
  public function typecast(array &$config, $id = 'blazy.settings') {
    // Do nothing, allows extenders without UI to forget about it.
  }

}
