<?php

namespace Drupal\blazy;

/**
 * Defines re-usable services and functions for blazy plugins.
 */
interface BlazyInterface {

  /**
   * Merge data with a new one with an optional key.
   */
  public function merge(array $data, array $element, $key = NULL): array;

  /**
   * Returns any config, or keyed by the $key.
   *
   * @todo use D8 approach for this.
   */
  public function config(
    $key = '',
    $default = NULL,
    $id = 'blazy.settings',
    array $defaults = []
  );

  /**
   * Typecast the needed settings, blazy-related module can override.
   *
   * Performance wise, typecasting should be at the form submit as calling
   * self::config() can be called multiple times. See sample below.
   *
   * @see Drupal\blazy_ui\Form\BlazySettingsForm::submitForm()
   * @see Drupal\slick_ui\Form\SlickSettingsForm::submitForm()
   */
  public function typecast(array &$config, $id = 'blazy.settings');

}
