<?php

namespace Drupal\blazy;

/**
 * Defines re-usable services and functions for blazy plugins.
 */
interface BlazyManagerInterface extends BlazyInterface {

  /**
   * Returns array of needed assets suitable for #attached property.
   *
   * @return array
   *   Returns the required library array.
   */
  public function attach(array $attach);

  /**
   * Returns the cache id based on few generic setting values.
   */
  public function getCacheId(array $settings = []);

  /**
   * Returns the common settings inherited down to each item.
   */
  public function getCommonSettings();

  /**
   * Returns available image styles with crop in the name.
   */
  public function cropStyles();

  /**
   * Checks if an image style contains crop effect.
   *
   * @param string $style
   *   The image style to check for.
   *
   * @return object|bool
   *   Returns the image style instance if it contains crop effect, else FALSE.
   */
  public function isCrop($style);

  /**
   * Returns drupalSettings for IO.
   */
  public function getIoSettings(array $attach = []);

  /**
   * Gets the supported lightboxes.
   *
   * @return array
   *   The supported lightboxes.
   */
  public function getLightboxes();

  /**
   * Gets the supported image effects.
   *
   * @return array
   *   The supported effects.
   */
  public function getImageEffects();

  /**
   * Returns available optionsets for select options.
   */
  public function getOptionsetOptions(array $entities = []);

  /**
   * Checks for Blazy formatter such as from within a Views style plugin.
   *
   * Ensures the settings traverse up to the container where Blazy is clueless.
   * The supported plugins can add [data-blazy] attribute into its container
   * containing $settings['blazy_data'] converted into [data-blazy] JSON.
   * This allows Blazy Grid, or other Views styles, lacking of UI, to have
   * additional settings extracted from the first Blazy formatter found.
   * Such as media switch/ lightbox. This way the container can add relevant
   * attributes to its container, etc. Also applies to entity references where
   * Blazy is not the main formatter, instead embedded as part of the parent's.
   *
   * @param array $settings
   *   The settings being modified.
   * @param array $item
   *   The item containing settings or item keys, not image item.
   */
  public function isBlazy(array &$settings, array $item = []);

  /**
   * Collects defined skins as registered via hook_MODULE_NAME_skins_info().
   */
  public function buildSkins($namespace, $skin_class, $methods = []);

}
